@@ -1,15 +1,8 @@
 import requests
-from dataclasses import dataclass
-from blockfrost.utils import object_request_wrapper, object_list_request_wrapper
+from blockfrost.utils import request_wrapper, list_request_wrapper
 
 
-@dataclass
-class AssetsResponse:
-    asset: str
-    quantity: str
-
-
-@object_list_request_wrapper(AssetsResponse)
+@list_request_wrapper
 def assets(self, **kwargs):
     """
     List of assets.
@@ -18,16 +11,16 @@ def assets(self, **kwargs):
 
     :param return_type: Optional. "object", "json" or "pandas". Default: "object".
     :type return_type: str
-    :param gather_pages: Optional. Default: 100. Will collect all pages into one return
+    :param gather_pages: Optional. Default: false. Will collect all pages into one return
     :type gather_pages: bool
-    :param count: Optional. Default: 1. The number of results displayed on one page.
+    :param count: Optional. Default: 100. The number of results displayed on one page.
     :type count: int
     :param page: Optional. The page number for listing the results.
     :type page: int
     :param order: Optional. "asc" or "desc". Default: "asc".
     :type order: str
-    :returns A list of AssetResponse objects.
-    :rtype [AssetResponse]
+    :returns A list of objects.
+    :rtype [Namespace]
     :raises ApiError: If API fails
     :raises Exception: If the API response is somehow malformed.
     """
@@ -38,53 +31,7 @@ def assets(self, **kwargs):
     )
 
 
-@dataclass
-class AssetResponse:
-    @dataclass
-    class OnchainMetadata:
-        name: str
-        image: str
-        additional_properties: dict
-
-        def __init__(self, name: str, image: str, **kwargs) -> None:
-            self.name = name
-            self.image = image
-            self.additional_properties = kwargs
-
-    @dataclass
-    class Metadata:
-        name: str
-        description: str
-        ticker: str
-        url: str
-        logo: str
-        decimals: int
-
-    asset: str
-    policy_id: str
-    asset_name: str
-    fingerprint: str
-    quantity: str
-    initial_mint_tx_hash: str
-    mint_or_burn_count: int
-    onchain_metadata: OnchainMetadata
-    metadata: Metadata
-
-    def __init__(self, asset: str, policy_id: str, asset_name: str, fingerprint: str, quantity: str,
-                 initial_mint_tx_hash: str, mint_or_burn_count: int, onchain_metadata: OnchainMetadata,
-                 metadata: Metadata = None) -> None:
-        self.asset = asset
-        self.policy_id = policy_id
-        self.asset_name = asset_name
-        self.fingerprint = fingerprint
-        self.quantity = quantity
-        self.initial_mint_tx_hash = initial_mint_tx_hash
-        self.mint_or_burn_count = mint_or_burn_count
-        self.onchain_metadata = self.OnchainMetadata(**onchain_metadata) if onchain_metadata is not None else None
-        self.metadata = self.Metadata(**metadata) if metadata is not None else None
-
-
-@object_request_wrapper(AssetResponse)
+@request_wrapper
 def asset(self, asset: str, **kwargs):
     """
     Information about a specific asset
@@ -95,8 +42,8 @@ def asset(self, asset: str, **kwargs):
     :type asset: str
     :param return_type: Optional. "object", "json" or "pandas". Default: "object".
     :type return_type: str
-    :returns AssetResponse object.
-    :rtype AssetResponse
+    :returns object.
+    :rtype: Namespace
     :raises ApiError: If API fails
     :raises Exception: If the API response is somehow malformed.
     """
@@ -106,14 +53,7 @@ def asset(self, asset: str, **kwargs):
     )
 
 
-@dataclass
-class AssetHistoryResponse:
-    tx_hash: str
-    action: str
-    amount: str
-
-
-@object_list_request_wrapper(AssetHistoryResponse)
+@list_request_wrapper
 def asset_history(self, asset: str, **kwargs):
     """
     History of a specific asset
@@ -124,16 +64,16 @@ def asset_history(self, asset: str, **kwargs):
     :type asset: str
     :param return_type: Optional. "object", "json" or "pandas". Default: "object".
     :type return_type: str
-    :param gather_pages: Optional. Default: 100. Will collect all pages into one return
+    :param gather_pages: Optional. Default: false. Will collect all pages into one return
     :type gather_pages: bool
-    :param count: Optional. Default: 1. The number of results displayed on one page.
+    :param count: Optional. Default: 100. The number of results displayed on one page.
     :type count: int
     :param page: Optional. The page number for listing the results.
     :type page: int
     :param order: Optional. "asc" or "desc". Default: "asc".
     :type order: str
-    :returns A list of AssetHistoryResponse objects.
-    :rtype [AssetHistoryResponse]
+    :returns A list of objects.
+    :rtype [Namespace]
     :raises ApiError: If API fails
     :raises Exception: If the API response is somehow malformed.
     """
@@ -144,15 +84,7 @@ def asset_history(self, asset: str, **kwargs):
     )
 
 
-@dataclass
-class AssetTransactionResponse:
-    tx_hash: str
-    tx_index: int
-    block_height: int
-    block_time: int
-
-
-@object_list_request_wrapper(AssetTransactionResponse)
+@list_request_wrapper
 def asset_transactions(self, asset: str, **kwargs):
     """
     List of a specific asset transactions
@@ -163,16 +95,16 @@ def asset_transactions(self, asset: str, **kwargs):
     :type asset: str
     :param return_type: Optional. "object", "json" or "pandas". Default: "object".
     :type return_type: str
-    :param gather_pages: Optional. Default: 100. Will collect all pages into one return
+    :param gather_pages: Optional. Default: false. Will collect all pages into one return
     :type gather_pages: bool
-    :param count: Optional. Default: 1. The number of results displayed on one page.
+    :param count: Optional. Default: 100. The number of results displayed on one page.
     :type count: int
     :param page: Optional. The page number for listing the results.
     :type page: int
     :param order: Optional. "asc" or "desc". Default: "asc".
     :type order: str
-    :returns A list of AssetTransactionResponse objects.
-    :rtype [AssetTransactionResponse]
+    :returns A list of objects.
+    :rtype [Namespace]
     :raises ApiError: If API fails
     :raises Exception: If the API response is somehow malformed.
     """
@@ -183,13 +115,7 @@ def asset_transactions(self, asset: str, **kwargs):
     )
 
 
-@dataclass
-class AssetAddressResponse:
-    address: str
-    quantity: str
-
-
-@object_list_request_wrapper(AssetAddressResponse)
+@list_request_wrapper
 def asset_addresses(self, asset: str, **kwargs):
     """
     List of a addresses containing a specific asset
@@ -200,16 +126,16 @@ def asset_addresses(self, asset: str, **kwargs):
     :type asset: str
     :param return_type: Optional. "object", "json" or "pandas". Default: "object".
     :type return_type: str
-    :param gather_pages: Optional. Default: 100. Will collect all pages into one return
+    :param gather_pages: Optional. Default: false. Will collect all pages into one return
     :type gather_pages: bool
-    :param count: Optional. Default: 1. The number of results displayed on one page.
+    :param count: Optional. Default: 100. The number of results displayed on one page.
     :type count: int
     :param page: Optional. The page number for listing the results.
     :type page: int
     :param order: Optional. "asc" or "desc". Default: "asc".
     :type order: str
-    :returns A list of AssetAddressResponse objects.
-    :rtype [AssetAddressResponse]
+    :returns A list of objects.
+    :rtype [Namespace]
     :raises ApiError: If API fails
     :raises Exception: If the API response is somehow malformed.
     """
@@ -220,13 +146,7 @@ def asset_addresses(self, asset: str, **kwargs):
     )
 
 
-@dataclass
-class AssetPolicyResponse:
-    asset: str
-    quantity: str
-
-
-@object_list_request_wrapper(AssetPolicyResponse)
+@list_request_wrapper
 def assets_policy(self, policy_id: str, **kwargs):
     """
     List of asset minted under a specific policy
@@ -237,16 +157,16 @@ def assets_policy(self, policy_id: str, **kwargs):
     :type policy_id: str
     :param return_type: Optional. "object", "json" or "pandas". Default: "object".
     :type return_type: str
-    :param gather_pages: Optional. Default: 100. Will collect all pages into one return
+    :param gather_pages: Optional. Default: false. Will collect all pages into one return
     :type gather_pages: bool
-    :param count: Optional. Default: 1. The number of results displayed on one page.
+    :param count: Optional. Default: 100. The number of results displayed on one page.
     :type count: int
     :param page: Optional. The page number for listing the results.
     :type page: int
     :param order: Optional. "asc" or "desc". Default: "asc".
     :type order: str
-    :returns A list of PolicyAssetResponse objects.
-    :rtype [PolicyAssetResponse]
+    :returns A list of objects.
+    :rtype [Namespace]
     :raises ApiError: If API fails
     :raises Exception: If the API response is somehow malformed.
     """
